OpenModes
=========

A Method of Moments (Boundary Element Method) code designed to find the
modes of open resonators such as meta-atoms (the building blocks of
metamaterials), (nano) antennas, scattering particles etc. Using these
modes, broadband models of these elements can be created, enabling
excitation, coupling between them and scattering to be solved easily.

References
----------

The techniques used in this package, and the scientific results
obtained, are described in the following publications and presentations:

-   *Interference between the modes of an all-dielectric meta-atom*,
    [2017 paper](http://dx.doi.org/10.1103/PhysRevApplied.7.034006) or
    [2016 arXiv preprint](https://arxiv.org/abs/1610.04980)
-   *Resonant dynamics of arbitrarily shaped meta-atoms*, [2014
    published paper](http://dx.doi.org/10.1103/PhysRevB.90.075108) or
    [2014 arXiv preprint](http://arxiv.org/abs/1405.3759)
-   *Modes in open metamaterial and nanophotonic systems*, [web
    presentation](http://people.physics.anu.edu.au/~dap124/aip2014/).

Documentation
-------------

Documentation is hosted on [Read the Docs](http://openmodes.readthedocs.io/en/latest/)

Installation
------------

A [docker image](https://hub.docker.com/r/davidpowell/openmodes/) is available which contains
the OpenModes, all required packages, the Jupyter web-based notebook interface and example notebooks.

See the [installation instructions](http://openmodes.readthedocs.io/en/latest/install.html)
for full details of how to install OpenModes via docker, or directly onto your machine.

The source is available on [GitHub](https://github.com/DavidPowell/OpenModes), and binary packages
are available from the [Python Package Index](https://pypi.python.org/pypi/OpenModes).

Author
------

This program was written by David Powell, a Senior Lecturer with the
School of Engineering and Information Technology at the University of
New South Wales, Canberra Campus.
